@@ -1,5 +1,4 @@
 from psycopg2 import sql
-from ..DataStructures.ObjEvmToken import ObjEvmToken
 from ..rupine_db import herokuDbAccess
 
 class ObjDmhNetworkStatisticHistory:
@@ -109,6 +108,29 @@ def getNetworkHistory(connection, schema, gecko_id):
         FROM {}.dwh_network_statistics_history WHERE gecko_id=%s").format(sql.Identifier(schema))
     result = herokuDbAccess.fetchDataInDatabase(query, [gecko_id], connection)    
     
+    # parse into objects
+    rows = []
+    for tok in result:
+        addRow = ParseDataIntoObj(tok)
+        rows.append(addRow)
+
+    # return objects
+    return rows
+
+def getNetworkHistory(connection, schema, gecko_id, time_start, time_end):
+    
+    # query database    
+    query = sql.SQL("SELECT gecko_id, gecko_market_cap_rank, gecko_market_cap, gecko_current_price, gecko_total_volume, \
+            twitter_follower, twitter_hashtag_count, github_total_commits, github_contributer_gte_100, \
+            github_contributer_lt_100_gte_10, github_contributer_lt_10, github_contributer_monthly_gte_100, \
+            github_contributer_monthly_lt_100, defilama_tvl, created_at, modified_at, reddit_subscribers, \
+            reddit_average_posts_48h, reddit_average_comments_48h, reddit_accounts_active_48h, github_forks, \
+            github_stars, github_subscribers, github_pull_requests_merged, github_pull_request_contributors, \
+            github_commit_count_4_weeks, timestamp \
+        FROM {}.dwh_network_statistics_history \
+        WHERE gecko_id=%s AND timestamp>%s AND timestamp<%s").format(sql.Identifier(schema))
+    result = herokuDbAccess.fetchDataInDatabase(query, [gecko_id, time_start, time_end], connection)    
+    
     # parse into objects
     rows = []
     for tok in result:
